@@ -52,11 +52,12 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
         "expressions",
         "plugin",
         "editable",
+        "plugin_config",
     )
 
     def __init__(
         self,
-        plugin="datagrid",
+        plugin="Datagrid",
         columns=None,
         row_pivots=None,
         column_pivots=None,
@@ -93,7 +94,8 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
                 expressions which are applied to the view.
             plugin (:obj:`str`/:obj:`perspective.Plugin`): Which plugin to
                 select by default.
-            plugin_config (:obj:`dict`): Custom config for all plugins by name.
+            plugin_config (:obj:`dict`): A configuration for the plugin, i.e.
+                the datagrid plugin or a chart plugin.
             dark (:obj:`bool`): Whether to invert the color theme.
             editable (:obj:`bool`): Whether to allow editability using the grid.
 
@@ -264,7 +266,8 @@ class PerspectiveViewer(PerspectiveTraitlets, object):
         self.expressions = []
         self.aggregates = {}
         self.columns = []
-        self.plugin = "datagrid"
+        self.plugin = "Datagrid"
+        self.plugin_config = {}
         self.editable = False
 
     def delete(self, delete_table=True):
